BMapCom.Controller.create(function() {

    var $ = function(q) {
        return document.querySelector(q)
    };

    var pageParamCache = {};
    var imageListView;

    var fixImageData = function(result) {
        var list = result.image.list;
        var ugcFixedData = {
            'showTotal': true,
            'total': result.image.total,
            'order': result.image.order,
            'showSort': true
        };
        ugcFixedData.title = list[0].cn_name || '百度地图';
        ugcFixedData.list = list.map(function(item, index) {
            var data = {};
            data.imageUrl = item.imgUrl;
            data.userName = item.username;
            data.cnName = item.cn_name;
            data.comment = item.content;
            if (data.comment && data.comment.length > 15) {
                data.comment = data.comment.substr(0, 15) + '...';
            }
            data.index = index;

            return data;
        });
        return ugcFixedData;
    }

    var refreshImageListView = function(result) {
        var fixedImageData = fixImageData(result);
        imageListView.refresh(fixedImageData);
    }

    var renderUgc = function(imagePage, imageTpl, result) {

        var ugcFixedData = fixImageData(result);

        BMapCom.Plugin.use('ImageListView').then(function(ImageListView) {
            imageListView = ImageListView.instantiate(ugcFixedData, $('#imageUgcList'));
            imageListView.event.on('sort', function(rule) {
                if (rule == 'default') {
                    ugcSource.update({
                        'uid': pageParamCache.uid,
                        'sort': 2,
                        'type': 'sortPage'
                    });
                } else if (rule == 'time') {
                    ugcSource.update({
                        'uid': pageParamCache.uid,
                        'sort': 1,
                        'type': 'sortPage'
                    });
                }
            });
            imageListView.event.on('imageItemClick', function(index) {
                var entranceParam = {
                    "page": "imageDetailPage",
                    "pageParam": {
                        //必传参数
                        "uid": pageParamCache.uid,
                        "option": {
                            "imageFrom": "baidumap", //图片来源
                            "sort": ugcSource.sort,
                            "index": index
                        }
                    }
                }
                BMapCom.Kernel.notify('changePage', entranceParam);
            });
            imageListView.event.on('seeMoreClick', function() {
                var entranceParam = {
                    "page": "imageDetailPage",
                    "pageParam": {
                        //必传参数
                        "uid": pageParamCache.uid,
                        "option": {
                            "imageFrom": "baidumap", //图片来源
                            "sort": ugcSource.sort
                        }
                    }
                }
                BMapCom.Kernel.notify('changePage', entranceParam);
            });
        });
    }

    var renderAll = function(imagePage, imageTpl, result) {
        var list = result.image.list;
        var allFixedData = {
            'showTotal': false,
            'total': 0,
            'order': result.image.order,
            'showSort': false
        };
        allFixedData.title = '更多来源';
        allFixedData.list = list.map(function(item, index) {
            var data = {};
            data.imageUrl = item.imgUrl_mb || '';
            data.userName = item.username || '';
            data.cnName = item.cn_name || '';
            data.comment = item.content || '';
            if (data.comment && data.comment.length > 15) {
                data.comment = data.comment.substr(0, 15) + '...';
            }
            data.index = index;
            return data;
        });

        BMapCom.Plugin.use('ImageListView').then(function(ImageListView) {
            var imageListView = ImageListView.instantiate(allFixedData, $('#imageAllList'));
            imageListView.event.on('imageItemClick', function(index) {
                var entranceParam = {
                    "page": "imageDetailPage",
                    "pageParam": {
                        //必传参数
                        "uid": pageParamCache.uid,
                        "option": {
                            "index": index
                        }
                    }
                }
                BMapCom.Kernel.notify('changePage', entranceParam);
            });
            imageListView.event.on('seeMoreClick', function() {
                var entranceParam = {
                    "page": "imageDetailPage",
                    "pageParam": {
                        //必传参数
                        "uid": pageParamCache.uid,
                    }
                }
                BMapCom.Kernel.notify('changePage', entranceParam);
            });
        });
    }

    var ugcSourceDelegate = {
        search: function(uid, sort) {
            var self = this;
            //"http://client.map.baidu.com/detail?qt=ugcpic&startIndex=0&maxResults=4&orderBy=&uid=2cc3c8e8b9192acf4c2fdf92";
            var domain = "http://client.map.baidu.com/detail?"
            var param = [
                'qt=ugcpic',
                'startIndex=0',
                'maxResults=4',
                'orderBy=' + sort,
                'uid=' + uid
            ].join('&');
            var url = domain + param;

            console.log(url)
            return BMapCom.Loader.jsonp(url)
                .ok(function(result) {
                    self.onSourceLoadFinish(result.data);
                })
                .error(function() {
                    self.onSourceLoadFailed();
                });

        }
    }

    var allSourceDelegate = {
        search: function(uid) {
            var self = this;
            //http://client.map.baidu.com/detail?qt=allpic&ugcPic=0&triPic=10&uid=7aea43b7204d94e17c29bd34
            var domain = "http://client.map.baidu.com/detail?"
            var param = [
                'qt=allpic',
                'ugcPic=0',
                'triPic=10',
                'uid=' + uid
            ].join('&');
            var url = domain + param;


            return BMapCom.Loader.jsonp(url)
                .ok(function(result) {
                    self.onSourceLoadFinish(result.data);
                })
                .error(function() {
                    self.onSourceLoadFailed();
                });

        }
    }

    var ugcSource;

    var initMethod = function(imagePage, imageTpl) {
        imagePage.append(imageTpl.body());

        var evt = new BMapCom.EventDelegater($('#imageContainer'));
        evt.on('uploadImage:tap', function(e) {
            BMapCom.SysApi.getRuntimeInfo(BMapCom.SysApi.RUNTIME_INFO_TYPE.BDUSS, function(bduss) {
                var requestParam = {
                    "category": "mainmap",
                    "method": BMapCom.ComRequestMethod.DISPATCH,
                    "param": {
                        "target": "upload_photo_page",
                        "base_params": {
                            "user_bduss": bduss,
                            "place_type": "scope",
                            "uid": pageParamCache.uid
                        }
                    }
                };
                BMapCom.Kernel.notify('request', requestParam, function(result) {});
            });
        });

        $('#imageUploadImage').innerHTML = imageTpl.uploadImage();

        ugcSource = new BMapCom.DataSource();
        //绑定数据对象代理
        ugcSource
            .delegate(ugcSourceDelegate)
            .delegate({
                onSourceLoadFinish: function(result) {
                    if (this.type == 'firstPage') {
                        renderUgc(imagePage, imageTpl, result);
                    } else if (this.type == 'sortPage') {
                        refreshImageListView(result);
                    } else if (this.type == 'refreshPage') {
                        refreshImageListView(result);
                    }
                },
                startSourceLoad: function(param) {
                    this.type = param.type;
                    if (param.sort) {
                        this.sort = param.sort;
                    }
                    this.search(param.uid, this.sort);
                }
            });
        var allSource = new BMapCom.DataSource();
        //绑定数据对象代理
        allSource
            .delegate(allSourceDelegate)
            .delegate({
                onSourceLoadFinish: function(result) {
                    renderAll(imagePage, imageTpl, result);
                    BMapCom.Kernel.notify('webPageReady');
                },
                startSourceLoad: function(uid) {
                    this.search(uid);
                }
            });

        //绑定页面事件代理
        imagePage
            .delegate({
                shouldWaiting: function() {
                    return true;
                },
                onCreate: function(pageParam, ready) {
                    pageParamCache = pageParam;
                    ugcSource.update({
                        'uid': pageParam.uid,
                        'sort': 2, //2为默认排序
                        'type': 'firstPage'
                    });
                    allSource.update(pageParam.uid);
                },
                onDestory: function() {
                    renderContainer.innerHTML = "";
                }
            });

        BMapCom.Kernel.listen('refresh', function() {
            if (ugcSource) {
                //不传sort值，使用当前的排序规则
                ugcSource.update({
                    'uid': pageParamCache.uid,
                    'type': 'refreshPage'
                });
            }
        });

    }


    return {
        initWithPage: initMethod
    }
});