BMapCom.Controller.create(function() {

    var $ = function(q) {
        return document.querySelector(q)
    };

    var pageParamCache = {};
    var imageListView;
    var imageListData = [];

    var fixImageData = function(result) {
        var list = result.image.list;
        var ugcFixedData = {
            'showTotal': true,
            'total': result.image.total,
            'order': result.image.order,
            'showSort': true
        };
        if (((ugcSource.pageNum + 1) * 10) < result.image.total) {
            ugcFixedData.showMore = true;
        } else {
            ugcFixedData.showMore = false;
        }
        ugcFixedData.title = list[0].cn_name || '百度地图';
        ugcFixedData.list = list.map(function(item, index) {
            var data = {};
            data.imageUrl = item.imgUrl;
            data.userName = item.username;
            data.cnName = item.cn_name;
            data.comment = item.content;
            if (data.comment && data.comment.length > 15) {
                data.comment = data.comment.substr(0, 15) + '...';
            }

            data.index = index + (ugcSource.imageNum ? ugcSource.imageNum : 0);

            return data;
        });
        ugcFixedData.imageNum = list ? list.length : 0;
        return ugcFixedData;
    };

    var refreshImageList = function(result) {
        var fixedImageData = fixImageData(result);
        ugcSource.imageNum = fixedImageData.imageNum;
        if (fixedImageData.showMore) {
            $('.il-foot').style.display = '';
        } else {
            $('.il-foot').style.display = 'none';
        }
        imageListView.refresh(fixedImageData);
    };

    var appendImageList = function(result) {
        var fixedImageData = fixImageData(result);
        ugcSource.imageNum += fixedImageData.imageNum;
        imageListView.append(fixedImageData);
    };

    var renderUgc = function(imagePage, imageTpl, result) {

        var ugcFixedData = fixImageData(result);

        //记录当前展示的图片数
        ugcSource.imageNum = ugcFixedData.imageNum;

        BMapCom.Plugin.use('ImageListView').then(function(ImageListView) {
            imageListView = ImageListView.instantiate(ugcFixedData, $('#imageUgcList'));

            if (!ugcFixedData.showMore) {
                $('.il-foot').style.display = 'none';
            }

            imageListView.event.on('sort', function(rule) {
                if (rule == 'default') {
                    ugcSource.update({
                        'uid': pageParamCache.uid,
                        'sort': 2,
                        'type': 'sortPage',
                        'pageNum': 0
                    });
                } else if (rule == 'time') {
                    ugcSource.update({
                        'uid': pageParamCache.uid,
                        'sort': 1,
                        'type': 'sortPage',
                        'pageNum': 0
                    });
                }
            });
            imageListView.event.on('imageItemClick', function(index) {
                var entranceParam = {
                    "page": "imageDetailPage",
                    "pageParam": {
                        //必传参数
                        "uid": pageParamCache.uid,
                        "option": {
                            "imageFrom": "baidumap", //图片来源
                            "sort": ugcSource.sort,
                            "index": index,
                            "imageList": {
                                "image": {
                                    "list" : imageListData
                                }
                            },
                            "imageNum": ugcSource.imageNum
                        }
                    }
                };
                BMapCom.Kernel.notify('changePage', entranceParam);
            });
            imageListView.event.on('seeMoreClick', function() {
                ugcSource.update({
                    'uid': pageParamCache.uid,
                    'sort': ugcSource.sort,
                    'type': 'morePage',
                    'pageNum': ugcSource.pageNum + 1
                });
            });
        });
    }

    var ugcSourceDelegate = {
        search: function(uid, sort, pageNum) {
            var self = this;
            //"http://client.map.baidu.com/detail?qt=ugcpic&startIndex=0&maxResults=4&orderBy=&uid=2cc3c8e8b9192acf4c2fdf92";
            var domain = "http://client.map.baidu.com/detail?"
            var param = [
                'qt=ugcpic',
                'startIndex=' + pageNum,
                'maxResults=10',
                'orderBy=' + sort,
                'uid=' + uid
            ].join('&');
            var url = domain + param;

            return BMapCom.Loader.jsonp(url)
                .ok(function(result) {
                    self.onSourceLoadFinish(result.data);
                })
                .error(function() {
                    self.onSourceLoadFailed();
                });

        }
    };


    var ugcSource;

    var initMethod = function(moreImagePageCtrl, moreImageTpl) {
        moreImagePageCtrl.append(moreImageTpl.body());

        var evt = new BMapCom.EventDelegater($('#imageContainer'));
        evt.on('uploadImage:tap', function(e) {
            BMapCom.SysApi.getRuntimeInfo(BMapCom.SysApi.RUNTIME_INFO_TYPE.BDUSS, function(bduss) {
                var requestParam = {
                    "category": "mainmap",
                    "method": BMapCom.ComRequestMethod.DISPATCH,
                    "param": {
                        "target": "upload_photo_page",
                        "base_params": {
                            "user_bduss": bduss,
                            "place_type": "scope",
                            "uid": pageParamCache.uid
                        }
                    }
                };
                BMapCom.Kernel.notify('request', requestParam, function(result) {});
            });
        });

        $('#imageUploadImage').innerHTML = moreImageTpl.uploadImage();

        ugcSource = new BMapCom.DataSource();
        //绑定数据对象代理
        ugcSource
            .delegate(ugcSourceDelegate)
            .delegate({
                onSourceLoadFinish: function(result) {
                    if (this.type == 'firstPage') {
                        imageListData = imageListData.concat(result.image.list);
                        renderUgc(moreImagePageCtrl, moreImageTpl, result);
                    } else if (this.type == 'morePage') {
                        imageListData = imageListData.concat(result.image.list);
                        appendImageList(result);
                    } else if (this.type == 'refreshPage') {
                        refreshImageList(result);
                    } else if (this.type == 'sortPage') {
                        refreshImageList(result);
                    }

                    BMapCom.Kernel.notify('webPageReady');
                },
                startSourceLoad: function(param) {
                    this.type = param.type;
                    if (param.hasOwnProperty('pageNum')) {
                        this.pageNum = param.pageNum;
                    }
                    if (param.sort) {
                        this.sort = param.sort;
                    }
                    this.search(param.uid, this.sort, this.pageNum);
                }
            });

        //绑定页面事件代理
        moreImagePageCtrl
            .delegate({
                shouldWaiting: function() {
                    return true;
                },
                onCreate: function(pageParam, ready) {
                    pageParamCache = pageParam;
                    ugcSource.update({
                        'uid': pageParam.uid,
                        'sort': 2, //2为默认排序
                        'type': 'firstPage',
                        'pageNum': 0
                    });
                },
                onDestory: function() {
                    renderContainer.innerHTML = "";
                }
            });

        BMapCom.Kernel.listen('refresh', function() {
            if (ugcSource) {
                //不传sort值，使用当前的排序规则
                ugcSource.update({
                    'uid': pageParamCache.uid,
                    'sort': 2, //2为默认排序
                    'type': 'refreshPage',
                    'pageNum': 0
                });
            }
        });

    }


    return {
        initWithPage: initMethod
    }
});